##  Filtering and Searching in the Discovery Inbox
Select Filter to apply parameters to the discovered SAP list items. Parameters include:
Filter Parameter | Description
---|---
Status | Filter the list by the status of the discovered item, including Linked, Action needed, Review needed, or Rejected. This helps you identify items that need your attention or review services you’ve already linked or rejected.
Classification | Filter by classification, such as SaaS Product (for example, SAP Ariba Procurement), SaaS ERP (for example, SAP S/4HANA Cloud), On-Prem System (for example, SAP Netweaver), or On-Prem ERP (for example, SAP ERP 6).
Product | Filter by product name, such as SAP S/4HANA Cloud. This allows you to review all tenants of a specific product at once.
System role | Filter by system role in SAP Cloud ALM, such as PROD, DEVELOP, or TEST. Link only production systems to the inventory. This filter helps you manage tenants that aren’t in production.
Last action by | Filter the list by the user or system that performed the most recent action on the discovered items. This helps you review services that have already been linked or rejected.


### Quick Filters
The status cards at the top of the discoveries list act as quick filters. For example, select theAction needed card to remove all current filters and apply the filter to only list items requiring action. To remove all filters, select the Total card.
